@@ -8,6 +8,10 @@
 #  source("https://bioconductor.org/biocLite.R")
 #  biocLite("Biostrings")
 
+## ----eval=FALSE----------------------------------------------------------
+#  source("https://bioconductor.org/biocLite.R")
+#  biocLite(c('Biostrings', 'GenomicRanges', 'bamsignals', 'IRanges', 'Rsamtools', 'snpStats'))
+
 ## ----eval=FALSE----------------------------------------------------------
 #  install.packages("devtools")
 #  library("devtools")
@@ -194,7 +198,7 @@ findSpecies("Cattle")
 #  +             )
 
 ## ---- fig.retina = NULL, fig.cap="Similarity between Pig and Cow", echo=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-knitr::include_graphics("./pigFlanking.jpg")
+knitr::include_graphics("./pigFlanking.png")
 
 ## ----eval =FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #        plotHit(
@@ -214,7 +218,7 @@ knitr::include_graphics("./pigFlanking.jpg")
 #  +             groupColor = c("blue", "red"))
 
 ## ---- fig.retina = NULL, fig.cap="Similarity between Pig and Cow, with added coverage and annotation", echo=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-knitr::include_graphics("./coverageExample.jpg")
+knitr::include_graphics("./coverageExample.png")
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  # Load the package
